"""
Proxidize: Proxy Tester
A multi-threaded proxy testing tool for HTTP/SOCKS proxies
"""

__version__ = "1.0.3"
__author__ = "Proxidize"
__email__ = "support@proxidize.com"
__description__ = "Proxidize Proxy Tester - A multi-threaded proxy testing tool for HTTP/SOCKS proxies"

# ...existing code...